| MEBanalysis | R Documentation |
For a given field data it will provide analysis result through ANOVA table including gca and sca effect analysis.
MEBanalysis(data)
data |
Columns of dataset should be in order of block, line1,line2, cross number and response. |
Returns the ANOVA table of gca and sca effect analysis.
library(MEDesigns)
MEBanalysis(MEdata)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.